==> hubot-irc-0.0.3.tgz: package/lib/irc.js <==
var Adapter, Irc, IrcBot, Robot;
var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; }, __slice = Array.prototype.slice;

Robot = require('hubot').robot();

Adapter = require('hubot').adapter();

Irc = require('irc');

IrcBot = (function() {

  __extends(IrcBot, Adapter);

  function IrcBot() {
    IrcBot.__super__.constructor.apply(this, arguments);
  }

  IrcBot.prototype.send = function() {
    var str, strings, user, _i, _len, _results;
    user = arguments[0], strings = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    _results = [];
    for (_i = 0, _len = strings.length; _i < _len; _i++) {
      str = strings[_i];
      if (user.room) {
        console.log("" + user.room + " " + str);
        _results.push(this.bot.say(user.room, str));
      } else {
        console.log("" + user.name + " " + str);
        _results.push(this.bot.say(user.name, str));
      }
    }
    return _results;
  };

  IrcBot.prototype.reply = function() {
    var str, strings, user, _i, _len, _results;
    user = arguments[0], strings = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    _results = [];
    for (_i = 0, _len = strings.length; _i < _len; _i++) {
      str = strings[_i];
      _results.push(this.send(user, "" + user.name + ": " + str));
    }
    return _results;
  };

  IrcBot.prototype.join = function(channel) {
    var self;
    self = this;
    return this.bot.join(channel, function() {
      return console.log('joined %s', channel);
    });
  };

  IrcBot.prototype.part = function(channel) {
    return this.bot.part(channel, function() {
      return console.log('left %s', channel);
    });
  };

  IrcBot.prototype.run = function() {
    var bot, client_options, next_id, options, self, user_id;
    self = this;
    options = {
      nick: process.env.HUBOT_IRC_NICK || this.robot.name,
      port: process.env.HUBOT_IRC_PORT,
      rooms: process.env.HUBOT_IRC_ROOMS.split(","),
      server: process.env.HUBOT_IRC_SERVER,
      password: process.env.HUBOT_IRC_PASSWORD,
      nickpass: process.env.HUBOT_IRC_NICKSERV_PASSWORD,
      fakessl: process.env.HUBOT_IRC_SERVER_FAKE_SSL != null,
      unflood: process.env.HUBOT_IRC_UNFLOOD != null,
      debug: process.env.HUBOT_IRC_DEBUG != null,
      usessl: process.env.HUBOT_IRC_USESSL != null
    };
    client_options = {
      password: options.password,
      debug: options.debug,
      port: options.port,
      stripColors: true,
      secure: options.usessl,
      selfSigned: options.fakessl,
      floodProtection: options.unflood
    };
    if (!options.nickpass) client_options['channels'] = options.rooms;
    bot = new Irc.Client(options.server, options.nick, client_options);
    next_id = 1;
    user_id = {};
    if (options.nickpass != null) {
      bot.addListener('notice', function(from, to, text) {
        var room, _i, _len, _ref, _results;
        if (from === 'NickServ' && text.indexOf('registered') !== -1) {
          return bot.say('NickServ', "identify " + options.nickpass);
        } else if (options.nickpass && from === 'NickServ' && text.indexOf('Password accepted') !== -1) {
          _ref = options.rooms;
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            room = _ref[_i];
            _results.push(this.join(room));
          }
          return _results;
        }
      });
    }
    bot.addListener('message', function(from, to, message) {
      var id, user;
      console.log("From " + from + " to " + to + ": " + message);
      user = self.userForName(from);
      if (user == null) {
        id = (new Date().getTime() / 1000).toString().replace('.', '');
        user = self.userForId(id);
        user.name = from;
      }
      if (to.match(/^[&#]/)) {
        user.room = to;
        console.log("" + to + " <" + from + "> " + message);
      } else {
        user.room = null;
        console.log("msg <" + from + "> " + message);
      }
      return self.receive(new Robot.TextMessage(user, message));
    });
    bot.addListener('error', function(message) {
      return console.error('ERROR: %s: %s', message.command, message.args.join(' '));
    });
    bot.addListener('pm', function(nick, message) {
      return console.log('Got private message from %s: %s', nick, message);
    });
    bot.addListener('join', function(channel, who) {
      return console.log('%s has joined %s', who, channel);
    });
    bot.addListener('part', function(channel, who, reason) {
      return console.log('%s has left %s: %s', who, channel, reason);
    });
    bot.addListener('kick', function(channel, who, _by, reason) {
      return console.log('%s was kicked from %s by %s: %s', who, channel, _by, reason);
    });
    bot.addListener('invite', function(channel, from) {
      console.log('%s invite you to join %s', from, channel);
      return bot.join(channel);
    });
    return this.bot = bot;
  };

  return IrcBot;

})();

exports.use = function(robot) {
  return new IrcBot(robot);
};

==> hubot-irc-0.0.5.tgz: package/lib/irc.js <==
var Adapter, Irc, IrcBot, Robot;
var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; }, __slice = Array.prototype.slice;

Robot = require('hubot').robot();

Adapter = require('hubot').adapter();

Irc = require('irc');

IrcBot = (function() {

  __extends(IrcBot, Adapter);

  function IrcBot() {
    IrcBot.__super__.constructor.apply(this, arguments);
  }

  IrcBot.prototype.send = function() {
    var str, strings, user, _i, _len, _results;
    user = arguments[0], strings = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    _results = [];
    for (_i = 0, _len = strings.length; _i < _len; _i++) {
      str = strings[_i];
      if (user.room) {
        console.log("" + user.room + " " + str);
        _results.push(this.bot.say(user.room, str));
      } else {
        console.log("" + user.name + " " + str);
        _results.push(this.bot.say(user.name, str));
      }
    }
    return _results;
  };

  IrcBot.prototype.reply = function() {
    var str, strings, user, _i, _len, _results;
    user = arguments[0], strings = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
    _results = [];
    for (_i = 0, _len = strings.length; _i < _len; _i++) {
      str = strings[_i];
      _results.push(this.send(user, "" + user.name + ": " + str));
    }
    return _results;
  };

  IrcBot.prototype.join = function(channel) {
    var self;
    self = this;
    return this.bot.join(channel, function() {
      return console.log('joined %s', channel);
    });
  };

  IrcBot.prototype.part = function(channel) {
    return this.bot.part(channel, function() {
      return console.log('left %s', channel);
    });
  };

  IrcBot.prototype.run = function() {
    var bot, client_options, next_id, options, self, user_id;
    self = this;
    options = {
      nick: process.env.HUBOT_IRC_NICK || this.robot.name,
      port: process.env.HUBOT_IRC_PORT,
      rooms: process.env.HUBOT_IRC_ROOMS.split(","),
      server: process.env.HUBOT_IRC_SERVER,
      password: process.env.HUBOT_IRC_PASSWORD,
      nickpass: process.env.HUBOT_IRC_NICKSERV_PASSWORD,
      fakessl: process.env.HUBOT_IRC_SERVER_FAKE_SSL != null,
      unflood: process.env.HUBOT_IRC_UNFLOOD != null,
      debug: process.env.HUBOT_IRC_DEBUG != null,
      usessl: process.env.HUBOT_IRC_USESSL != null
    };
    client_options = {
      password: options.password,
      debug: options.debug,
      port: options.port,
      stripColors: true,
      secure: options.usessl,
      selfSigned: options.fakessl,
      floodProtection: options.unflood
    };
    if (!options.nickpass) client_options['channels'] = options.rooms;
    bot = new Irc.Client(options.server, options.nick, client_options);
    next_id = 1;
    user_id = {};
    if (options.nickpass != null) {
      bot.addListener('notice', function(from, to, text) {
        var room, _i, _len, _ref, _results;
        if (from === 'NickServ' && text.indexOf('registered') !== -1) {
          return bot.say('NickServ', "identify " + options.nickpass);
        } else if (options.nickpass && from === 'NickServ' && (text.indexOf('Password accepted') !== -1 || text.indexOf('identified') !== -1)) {
          _ref = options.rooms;
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            room = _ref[_i];
            _results.push(this.join(room));
          }
          return _results;
        }
      });
    }
    bot.addListener('message', function(from, to, message) {
      var id, user;
      console.log("From " + from + " to " + to + ": " + message);
      user = self.userForName(from);
      if (user == null) {
        id = (new Date().getTime() / 1000).toString().replace('.', '');
        user = self.userForId(id);
        user.name = from;
      }
      if (to.match(/^[&#]/)) {
        user.room = to;
        console.log("" + to + " <" + from + "> " + message);
      } else {
        user.room = null;
        console.log("msg <" + from + "> " + message);
      }
      return self.receive(new Robot.TextMessage(user, message));
    });
    bot.addListener('error', function(message) {
      return console.error('ERROR: %s: %s', message.command, message.args.join(' '));
    });
    bot.addListener('pm', function(nick, message) {
      return console.log('Got private message from %s: %s', nick, message);
    });
    bot.addListener('join', function(channel, who) {
      return console.log('%s has joined %s', who, channel);
    });
    bot.addListener('part', function(channel, who, reason) {
      return console.log('%s has left %s: %s', who, channel, reason);
    });
    bot.addListener('kick', function(channel, who, _by, reason) {
      return console.log('%s was kicked from %s by %s: %s', who, channel, _by, reason);
    });
    bot.addListener('invite', function(channel, from) {
      console.log('%s invite you to join %s', from, channel);
      return bot.join(channel);
    });
    return this.bot = bot;
  };

  return IrcBot;

})();

exports.use = function(robot) {
  return new IrcBot(robot);
};
